\name{components.gdpcs}
\alias{components.gdpcs}
\title{Get Generalized Dynamic Principal Components From a gdpcs Object}
\description{
Get Generalized Dynamic Principal Components from a gdpcs object.
}


\usage{
\method{components}{gdpcs}(object, which_comp = 1)
}
\arguments{
  \item{object}{An object of class \code{gdpcs}, usually the result of \link{auto.gdpc}.}
  \item{which_comp}{Numeric vector indicating which components to get. Default is 1.}
}


\value{ A matrix whose columns are the desired dynamic principal components.}
\author{
Daniel Peña, Ezequiel Smucler, Victor Yohai
}



\seealso{
\code{\link{gdpc}}, \code{\link{auto.gdpc}}, \code{\link{plot.gdpc}}
}

\examples{
T <- 200 #length of series
m <- 200 #number of series
set.seed(1234)
f <- rnorm(T + 1)
x <- matrix(0, T, m)
u <- matrix(rnorm(T * m), T, m)
for (i in 1:m) {
    x[, i] <- 10 * sin(2 * pi * (i/m)) * f[1:T] + 10 * cos(2 * pi * (i/m)) * f[2:(T + 1)] + u[, i]
}
#Choose number of lags using the LOO criterion.
#k_max=2 to keep computation time low
autofit <- auto.gdpc(x, k_max = 2, auto_comp = FALSE, num_comp = 2) 
comps <- components.gdpcs(autofit, which_comp = c(1,2))
}

\keyword{ts}